.. Translator Component Toolkit documentation master file, created by
   sphinx-quickstart on Thu Jun 26 13:22:44 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Translator Component Toolkit's documentation!
========================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   intro
   components
   name_resolver
   node_normalizer
   translator_kpinfo
   translator_metakg
   translator_query
   translator_node
   TCT

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
